binance-clj.auth.signer

Small algorithm-independent signature boundary.

Small algorithm-independent signature boundary.
raw docstring

Signercljprotocol

algorithmclj

(algorithm signer)

Returns the stable signer algorithm keyword.

Returns the stable signer algorithm keyword.

signclj

(sign signer payload)

Signs a UTF-8 string and returns its wire representation.

Signs a UTF-8 string and returns its wire representation.
source

signer?clj

(signer? value)

Returns true when value implements the connector signer contract.

Returns true when value implements the connector signer contract.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries