binance-clj.endpoint

Declarative endpoint specifications and immutable registry operations.

Declarative endpoint specifications and immutable registry operations.
raw docstring

create-registryclj

(create-registry)
(create-registry specs)

Builds an immutable endpoint-id to spec map from a sequence of specs.

Builds an immutable endpoint-id to spec map from a sequence of specs.
sourceraw docstring

execution-typesclj

Execution semantics used for safety decisions such as retry policy.

Execution semantics used for safety decisions such as retry policy.
sourceraw docstring

http-methodsclj

HTTP methods available to V1 endpoint declarations.

HTTP methods available to V1 endpoint declarations.
sourceraw docstring

lookupclj

(lookup registry endpoint-id)

Returns endpoint spec or a normalized validation error for an unknown id.

Returns endpoint spec or a normalized validation error for an unknown id.
sourceraw docstring

permission-typesclj

Binance API-key permission families used by authenticated endpoint specs.

Binance API-key permission families used by authenticated endpoint specs.
sourceraw docstring

registerclj

(register registry spec)

Returns registry with spec added; duplicate endpoint ids are rejected.

Returns registry with spec added; duplicate endpoint ids are rejected.
sourceraw docstring

retry-policiesclj

Retry classifications. Commands are always :never in V1.

Retry classifications. Commands are always `:never` in V1.
sourceraw docstring

security-typesclj

Authentication contracts available to endpoint declarations.

Authentication contracts available to endpoint declarations.
sourceraw docstring

validate-specclj

(validate-spec spec)

Validates and returns one endpoint spec with an explicit retry policy.

Validates and returns one endpoint spec with an explicit retry policy.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries