binance-clj.spot

Unified public and signed Spot REST facade for connector consumers.

Unified public and signed Spot REST facade for connector consumers.
raw docstring

accountclj

Returns signed account information.

Returns signed account information.
sourceraw docstring

book-tickerclj

Returns best bid/ask data.

Returns best bid/ask data.
sourceraw docstring

cancel-orderclj

Cancels an active order.

Cancels an active order.
sourceraw docstring

create-market-streamclj

Creates a shared disconnected Spot market stream manager.

Creates a shared disconnected Spot market stream manager.
sourceraw docstring

create-user-streamclj

Creates a shared disconnected signed Spot User Data Stream manager.

Creates a shared disconnected signed Spot User Data Stream manager.
sourceraw docstring

depthclj

Returns an order-book snapshot.

Returns an order-book snapshot.
sourceraw docstring

exchange-infoclj

Returns exchange and symbol rules.

Returns exchange and symbol rules.
sourceraw docstring

my-tradesclj

Returns signed account trades.

Returns signed account trades.
sourceraw docstring

new-orderclj

Submits a locally validated MARKET/LIMIT order.

Submits a locally validated MARKET/LIMIT order.
sourceraw docstring

open-ordersclj

Returns signed open orders.

Returns signed open orders.
sourceraw docstring

pingclj

Tests REST connectivity.

Tests REST connectivity.
sourceraw docstring

query-orderclj

Returns a signed order query.

Returns a signed order query.
sourceraw docstring

server-timeclj

Returns Binance server time.

Returns Binance server time.
sourceraw docstring

submit-order!clj

Submits once and safely reconciles an unknown new-order execution.

Submits once and safely reconciles an unknown new-order execution.
sourceraw docstring

test-orderclj

Validates an order locally and through Binance without execution.

Validates an order locally and through Binance without execution.
sourceraw docstring

ticker-24hclj

Returns 24-hour ticker statistics.

Returns 24-hour ticker statistics.
sourceraw docstring

ticker-priceclj

Returns latest symbol price data.

Returns latest symbol price data.
sourceraw docstring

validate-orderclj

Runs pure local Binance symbol-filter validation without network access.

Runs pure local Binance symbol-filter validation without network access.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries