Public facade for authenticated Spot account and order-query endpoints.
Public facade for authenticated Spot account and order-query endpoints.
(account connector)(account connector options)Returns account information and BigDecimal-normalized balances.
Returns account information and BigDecimal-normalized balances.
(my-trades connector symbol-or-params)Returns account trades for a symbol or an explicit query map.
Returns account trades for a symbol or an explicit query map.
(open-orders connector)(open-orders connector symbol)Returns open orders for one symbol or, when omitted, all symbols.
Returns open orders for one symbol or, when omitted, all symbols.
(query-order connector params)Returns one order selected by order-id and/or original-client-order-id.
Returns one order selected by order-id and/or original-client-order-id.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |