binance-clj.spot.general

Public facade for Binance Spot general endpoints.

Public facade for Binance Spot general endpoints.
raw docstring

exchange-infoclj

(exchange-info connector)
(exchange-info connector params)

Returns exchange rules and symbol metadata without dropping unknown fields.

Returns exchange rules and symbol metadata without dropping unknown fields.
sourceraw docstring

pingclj

(ping connector)

Tests REST connectivity and returns the standard result envelope.

Tests REST connectivity and returns the standard result envelope.
sourceraw docstring

server-timeclj

(server-time connector)

Returns Binance server time in the standard result envelope.

Returns Binance server time in the standard result envelope.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries