binance-clj.spot.market

Public facade for Binance Spot market-data endpoints.

Public facade for Binance Spot market-data endpoints.
raw docstring

book-tickerclj

(book-ticker connector)
(book-ticker connector selection)

Returns best bid/ask for one, many, or all symbols.

Returns best bid/ask for one, many, or all symbols.
sourceraw docstring

depthclj

(depth connector symbol)
(depth connector symbol options)

Returns an order-book snapshot for symbol with optional limit/status params.

Returns an order-book snapshot for symbol with optional limit/status params.
sourceraw docstring

ticker-24hclj

(ticker-24h connector)
(ticker-24h connector selection)

Returns FULL/MINI 24-hour ticker data for one, many, or all symbols.

Returns FULL/MINI 24-hour ticker data for one, many, or all symbols.
sourceraw docstring

ticker-priceclj

(ticker-price connector)
(ticker-price connector selection)

Returns latest price for one, many, or all symbols.

Returns latest price for one, many, or all symbols.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries