binance-clj.spot.normalize

Lossless Public Spot REST response normalization.

Lossless Public Spot REST response normalization.
raw docstring

book-tickerclj

(book-ticker value)

Normalizes best bid/ask price and quantity objects or arrays.

Normalizes best bid/ask price and quantity objects or arrays.
sourceraw docstring

depthclj

(depth value)

Normalizes order-book bid/ask price and quantity levels.

Normalizes order-book bid/ask price and quantity levels.
sourceraw docstring

exchange-infoclj

(exchange-info value)

Normalizes known filter decimals and preserves all unknown exchange fields.

Normalizes known filter decimals and preserves all unknown exchange fields.
sourceraw docstring

pingclj

(ping value)

Validates and preserves the empty ping response object.

Validates and preserves the empty ping response object.
sourceraw docstring

server-timeclj

(server-time value)

Validates serverTime while preserving unknown response fields.

Validates serverTime while preserving unknown response fields.
sourceraw docstring

ticker-24hclj

(ticker-24h value)

Normalizes FULL/MINI 24-hour ticker financial fields.

Normalizes FULL/MINI 24-hour ticker financial fields.
sourceraw docstring

ticker-priceclj

(ticker-price value)

Normalizes ticker price objects or arrays.

Normalizes ticker price objects or arrays.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries