binance-clj.spot.streams

Public Spot market WebSocket stream names and shared connection facade.

Public Spot market WebSocket stream names and shared connection facade.
raw docstring

all-mini-tickersclj

(all-mini-tickers)

Returns Binance's current all-market mini ticker stream name.

Returns Binance's current all-market mini ticker stream name.
sourceraw docstring

book-tickerclj

(book-ticker symbol)

Returns an individual best bid/ask stream name.

Returns an individual best bid/ask stream name.
sourceraw docstring

close!clj

Closes the market-stream manager idempotently.

Closes the market-stream manager idempotently.
sourceraw docstring

connect!clj

Opens a market-stream connection and restores desired subscriptions.

Opens a market-stream connection and restores desired subscriptions.
sourceraw docstring

create-streamclj

(create-stream connector-client)
(create-stream connector-client options)

Creates a disconnected market-stream manager owned by client.

Creates a disconnected market-stream manager owned by client.
sourceraw docstring

partial-depthclj

(partial-depth symbol levels)
(partial-depth symbol levels update-ms)

Returns depth5/depth10/depth20, optionally at the 100 ms cadence.

Returns depth5/depth10/depth20, optionally at the 100 ms cadence.
sourceraw docstring

poll-event!clj

Returns the next normalized buffered market event.

Returns the next normalized buffered market event.
sourceraw docstring

renew!clj

Rotates the socket immediately and restores desired subscriptions.

Rotates the socket immediately and restores desired subscriptions.
sourceraw docstring

snapshotclj

Returns secret-safe connection and backpressure state.

Returns secret-safe connection and backpressure state.
sourceraw docstring

subscribe!clj

Adds one market stream to the desired subscription registry.

Adds one market stream to the desired subscription registry.
sourceraw docstring

tickerclj

(ticker symbol)

Returns an individual 24-hour ticker stream name.

Returns an individual 24-hour ticker stream name.
sourceraw docstring

unsubscribe!clj

Removes one market stream from the desired subscription registry.

Removes one market stream from the desired subscription registry.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries