binance-clj.spot.validation

Public Spot REST parameter validation and wire-name normalization.

Public Spot REST parameter validation and wire-name normalization.
raw docstring

depthclj

(depth {:keys [endpoint params] :as context})

Validates order-book params and resolves its limit-dependent weight.

Validates order-book params and resolves its limit-dependent weight.
sourceraw docstring

exchange-infoclj

(exchange-info {:keys [endpoint params] :as context})

Validates exchangeInfo selectors and returns wire-ready parameters.

Validates exchangeInfo selectors and returns wire-ready parameters.
sourceraw docstring

market-selectorclj

(market-selector {:keys [endpoint params] :as context})

Validates common symbol/symbols/symbol-status market parameters.

Validates common symbol/symbols/symbol-status market parameters.
sourceraw docstring

no-paramsclj

(no-params {:keys [endpoint params] :as context})

Rejects parameters for endpoints whose official contract has none.

Rejects parameters for endpoints whose official contract has none.
sourceraw docstring

ticker-24hclj

(ticker-24h {:keys [endpoint params] :as context})

Validates 24-hour ticker params and resolves its dynamic request weight.

Validates 24-hour ticker params and resolves its dynamic request weight.
sourceraw docstring

ticker-price-or-bookclj

(ticker-price-or-book {:keys [params] :as context})

Validates ticker price/book params and resolves 2-or-4 request weight.

Validates ticker price/book params and resolves 2-or-4 request weight.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries