binance-clj.transport

Small transport boundary shared by the pure request pipeline and adapters.

Small transport boundary shared by the pure request pipeline and adapters.
raw docstring

close!clj

(close! transport)

Closes a protocol or function-map transport; missing function-map close is a no-op.

Closes a protocol or function-map transport; missing function-map close is a no-op.
sourceraw docstring

responseclj

(response body metadata)

Creates a transport response envelope consumed by the generic pipeline.

Creates a transport response envelope consumed by the generic pipeline.
sourceraw docstring

response?clj

(response? value)

Returns true for normalized transport response envelopes.

Returns true for normalized transport response envelopes.
sourceraw docstring

send!clj

(send! transport request)

Executes request through a protocol or {:send! fn} adapter.

Executes request through a protocol or `{:send! fn}` adapter.
sourceraw docstring

Transportcljprotocol

Transport implementations execute abstract request maps and own resources.

Transport implementations execute abstract request maps and own resources.

close-transport!clj

(close-transport! transport)

Releases transport-owned resources.

Releases transport-owned resources.

send-request!clj

(send-request! transport request)

Executes an abstract connector request and returns an opaque response value.

Executes an abstract connector request and returns an opaque response value.
sourceraw docstring

transport?clj

(transport? value)

Returns true for protocol implementations or function-map transports.

Returns true for protocol implementations or function-map transports.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries