binance-clj.transport.websocket

JDK WebSocket boundary with exact ping/pong handling and text reassembly.

JDK WebSocket boundary with exact ping/pong handling and text reassembly.
raw docstring

close-socketclj

(close-socket transport socket)

Closes one socket through the transport boundary.

Closes one socket through the transport boundary.
sourceraw docstring

close-transport!clj

(close-transport! transport)

Closes the transport and all resources it owns.

Closes the transport and all resources it owns.
sourceraw docstring

create-transportclj

(create-transport)
(create-transport {:keys [connect-timeout-ms] :or {connect-timeout-ms 10000}})

Creates a reusable JDK WebSocket transport without opening a connection.

Creates a reusable JDK WebSocket transport without opening a connection.
sourceraw docstring

open!clj

(open! transport url callbacks)

Opens a socket through a protocol or injected transport map.

Opens a socket through a protocol or injected transport map.
sourceraw docstring

send-text!clj

(send-text! transport socket payload)

Sends a complete text frame through the transport boundary.

Sends a complete text frame through the transport boundary.
sourceraw docstring

transport?clj

(transport? value)

Returns true for protocol implementations or injectable function maps.

Returns true for protocol implementations or injectable function maps.
sourceraw docstring

WebSocketTransportcljprotocol

close-socket!clj

(close-socket! transport socket)

close-websocket-transport!clj

(close-websocket-transport! transport)

open-socket!clj

(open-socket! transport url callbacks)

send-text-frame!clj

(send-text-frame! transport socket text)
source

cljdoc builds & hosts documentation for Clojure/Script libraries