Small algorithm-independent signature boundary.
Small algorithm-independent signature boundary.
(algorithm signer)Returns the stable signer algorithm keyword.
Returns the stable signer algorithm keyword.
(sign signer payload)Signs a UTF-8 string and returns its wire representation.
Signs a UTF-8 string and returns its wire representation.
(signer? value)Returns true when value implements the connector signer contract.
Returns true when value implements the connector signer contract.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |