Client configuration schema, defaults, and safe public projection.
Client configuration schema, defaults, and safe public projection.
Binance's default receive window in milliseconds.
Binance's default receive window in milliseconds.
Official production and Spot Testnet base URLs used by V1.
Official production and Spot Testnet base URLs used by V1.
(live-trading-enabled? config)Returns true only when both production environment and explicit guard are set.
Returns true only when both production environment and explicit guard are set.
Binance's maximum accepted receive window in milliseconds.
Binance's maximum accepted receive window in milliseconds.
(normalize config)Validates client config and fills safe Testnet defaults.
Transport may be omitted while constructing/configuring a client, but execution
requires an injected protocol implementation or {:send! fn} map.
Validates client config and fills safe Testnet defaults.
Transport may be omitted while constructing/configuring a client, but execution
requires an injected protocol implementation or `{:send! fn}` map.(public-view config)Returns config suitable for diagnostics without credentials or runtime objects.
Returns config suitable for diagnostics without credentials or runtime objects.
(system-clock)Returns the current Unix epoch time in milliseconds.
Returns the current Unix epoch time in milliseconds.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |