Declarative endpoint specifications and immutable registry operations.
Declarative endpoint specifications and immutable registry operations.
(create-registry)(create-registry specs)Builds an immutable endpoint-id to spec map from a sequence of specs.
Builds an immutable endpoint-id to spec map from a sequence of specs.
Execution semantics used for safety decisions such as retry policy.
Execution semantics used for safety decisions such as retry policy.
HTTP methods available to V1 endpoint declarations.
HTTP methods available to V1 endpoint declarations.
(lookup registry endpoint-id)Returns endpoint spec or a normalized validation error for an unknown id.
Returns endpoint spec or a normalized validation error for an unknown id.
Binance API-key permission families used by authenticated endpoint specs.
Binance API-key permission families used by authenticated endpoint specs.
(register registry spec)Returns registry with spec added; duplicate endpoint ids are rejected.
Returns registry with spec added; duplicate endpoint ids are rejected.
Retry classifications. Commands are always :never in V1.
Retry classifications. Commands are always `:never` in V1.
Authentication contracts available to endpoint declarations.
Authentication contracts available to endpoint declarations.
(validate-spec spec)Validates and returns one endpoint spec with an explicit retry policy.
Validates and returns one endpoint spec with an explicit retry policy.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |