Precision-safe JSON parsing and conservative JSON generation.
Precision-safe JSON parsing and conservative JSON generation.
(read-json body)Reads one complete JSON value with keyword keys and BigDecimal decimals.
Empty response bodies become nil. Malformed JSON and trailing data are exposed as secret-safe normalized API errors without copying the body into ex-data.
Reads one complete JSON value with keyword keys and BigDecimal decimals. Empty response bodies become nil. Malformed JSON and trailing data are exposed as secret-safe normalized API errors without copying the body into ex-data.
(write-json value)Writes JSON after converting BigDecimal values to plain decimal strings.
Binance financial wire values are strings. Float, double, and Ratio values are rejected instead of allowing implicit precision loss or scientific notation.
Writes JSON after converting BigDecimal values to plain decimal strings. Binance financial wire values are strings. Float, double, and Ratio values are rejected instead of allowing implicit precision loss or scientific notation.
(write-websocket-json value)Writes WebSocket API JSON with exact decimal number tokens.
Unlike REST financial wire values, WebSocket API recvWindow is a JSON
DECIMAL parameter. BigDecimal is therefore retained as a JSON number while
inexact Clojure numeric types remain forbidden.
Writes WebSocket API JSON with exact decimal number tokens. Unlike REST financial wire values, WebSocket API `recvWindow` is a JSON DECIMAL parameter. BigDecimal is therefore retained as a JSON number while inexact Clojure numeric types remain forbidden.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |