Public facade for Binance Spot general endpoints.
Public facade for Binance Spot general endpoints.
(exchange-info connector)(exchange-info connector params)Returns exchange rules and symbol metadata without dropping unknown fields.
Returns exchange rules and symbol metadata without dropping unknown fields.
(ping connector)Tests REST connectivity and returns the standard result envelope.
Tests REST connectivity and returns the standard result envelope.
(server-time connector)Returns Binance server time in the standard result envelope.
Returns Binance server time in the standard result envelope.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |