Validation and wire normalization for V1 signed Spot REST endpoints.
Validation and wire normalization for V1 signed Spot REST endpoints.
(account {:keys [endpoint params] :as context})Validates account information options.
Validates account information options.
(cancel-order {:keys [config endpoint params] :as context})Validates a cancel command and enforces the production command guard.
Validates a cancel command and enforces the production command guard.
(my-trades {:keys [endpoint params] :as context})Validates account trade-list query combinations and dynamic weight.
Validates account trade-list query combinations and dynamic weight.
(new-order context)Validates an executable order, filters, and production safety guard.
Validates an executable order, filters, and production safety guard.
(open-orders {:keys [endpoint params] :as context})Validates optional open-orders symbol and resolves its dynamic weight.
Validates optional open-orders symbol and resolves its dynamic weight.
(query-order {:keys [endpoint params] :as context})Validates an order query by exchange id and/or original client id.
Validates an order query by exchange id and/or original client id.
(test-order context)Validates a non-executing test order and its local symbol filters.
Validates a non-executing test order and its local symbol filters.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |