Public Spot market WebSocket stream names and shared connection facade.
Public Spot market WebSocket stream names and shared connection facade.
(all-mini-tickers)Returns Binance's current all-market mini ticker stream name.
Returns Binance's current all-market mini ticker stream name.
(book-ticker symbol)Returns an individual best bid/ask stream name.
Returns an individual best bid/ask stream name.
Closes the market-stream manager idempotently.
Closes the market-stream manager idempotently.
Opens a market-stream connection and restores desired subscriptions.
Opens a market-stream connection and restores desired subscriptions.
(create-stream connector-client)(create-stream connector-client options)Creates a disconnected market-stream manager owned by client.
Creates a disconnected market-stream manager owned by client.
(partial-depth symbol levels)(partial-depth symbol levels update-ms)Returns depth5/depth10/depth20, optionally at the 100 ms cadence.
Returns depth5/depth10/depth20, optionally at the 100 ms cadence.
Returns the next normalized buffered market event.
Returns the next normalized buffered market event.
Rotates the socket immediately and restores desired subscriptions.
Rotates the socket immediately and restores desired subscriptions.
Returns secret-safe connection and backpressure state.
Returns secret-safe connection and backpressure state.
Adds one market stream to the desired subscription registry.
Adds one market stream to the desired subscription registry.
(ticker symbol)Returns an individual 24-hour ticker stream name.
Returns an individual 24-hour ticker stream name.
Removes one market stream from the desired subscription registry.
Removes one market stream from the desired subscription registry.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |