Small transport boundary shared by the pure request pipeline and adapters.
Small transport boundary shared by the pure request pipeline and adapters.
(close! transport)Closes a protocol or function-map transport; missing function-map close is a no-op.
Closes a protocol or function-map transport; missing function-map close is a no-op.
(response body metadata)Creates a transport response envelope consumed by the generic pipeline.
Creates a transport response envelope consumed by the generic pipeline.
(response? value)Returns true for normalized transport response envelopes.
Returns true for normalized transport response envelopes.
(send! transport request)Executes request through a protocol or {:send! fn} adapter.
Executes request through a protocol or `{:send! fn}` adapter.
Transport implementations execute abstract request maps and own resources.
Transport implementations execute abstract request maps and own resources.
(close-transport! transport)Releases transport-owned resources.
Releases transport-owned resources.
(send-request! transport request)Executes an abstract connector request and returns an opaque response value.
Executes an abstract connector request and returns an opaque response value.
(transport? value)Returns true for protocol implementations or function-map transports.
Returns true for protocol implementations or function-map transports.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |