JDK WebSocket boundary with exact ping/pong handling and text reassembly.
JDK WebSocket boundary with exact ping/pong handling and text reassembly.
(close-socket transport socket)Closes one socket through the transport boundary.
Closes one socket through the transport boundary.
(close-transport! transport)Closes the transport and all resources it owns.
Closes the transport and all resources it owns.
(create-transport)(create-transport {:keys [connect-timeout-ms] :or {connect-timeout-ms 10000}})Creates a reusable JDK WebSocket transport without opening a connection.
Creates a reusable JDK WebSocket transport without opening a connection.
(open! transport url callbacks)Opens a socket through a protocol or injected transport map.
Opens a socket through a protocol or injected transport map.
(send-text! transport socket payload)Sends a complete text frame through the transport boundary.
Sends a complete text frame through the transport boundary.
(transport? value)Returns true for protocol implementations or injectable function maps.
Returns true for protocol implementations or injectable function maps.
(close-socket! transport socket)(close-websocket-transport! transport)(open-socket! transport url callbacks)(send-text-frame! transport socket text)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |