Bounded non-blocking event buffer for WebSocket callback isolation.
Bounded non-blocking event buffer for WebSocket callback isolation.
(create-buffer)(create-buffer {:keys [capacity overflow-policy]
:or {capacity 1024 overflow-policy :drop-oldest}})Creates a bounded queue. WebSocket producer threads are never blocked.
Creates a bounded queue. WebSocket producer threads are never blocked.
(offer! {:keys [queue overflow-policy statistics]} event)Offers an event without blocking and returns true when it was retained.
Offers an event without blocking and returns true when it was retained.
Supported behavior when the bounded queue is full.
Supported behavior when the bounded queue is full.
(poll! {:keys [queue]} timeout-ms)Returns the next event, waiting up to timeout-ms; nil means no event.
Returns the next event, waiting up to timeout-ms; nil means no event.
(snapshot {:keys [queue capacity overflow-policy statistics]})Returns non-sensitive queue capacity, depth, policy, and counters.
Returns non-sensitive queue capacity, depth, policy, and counters.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |